@@ -64,6 +64,7 @@ import javax.swing.event.ChangeListener;
 import javax.swing.text.Caret;
 import org.netbeans.api.search.SearchHistory;
 import org.netbeans.api.search.SearchPattern;
+import org.netbeans.modules.search.ui.HideResultAction;
 import org.netbeans.modules.search.ui.ReplaceCheckableNode;
 import org.netbeans.modules.search.ui.ResultsOutlineSupport;
 import org.netbeans.modules.search.ui.UiUtils;
@@ -82,6 +83,7 @@ import org.openide.util.NbBundle;
 import org.openide.util.RequestProcessor;
 import org.openide.util.Task;
 import org.openide.util.TaskListener;
+import org.openide.util.actions.SystemAction;
 import org.openide.util.datatransfer.PasteType;
 import org.openide.util.lookup.Lookups;
 import org.openide.windows.OutputEvent;
@@ -198,6 +200,9 @@ public final class TextDetail implements Selectable {
     }
 
     private void showLine(int how) {
+        if (lineObj == null) {
+            return; // DataObject updated during opening of editor.
+        }
         if (how == DH_SHOW) {
             lineObj.show(ShowOpenType.NONE, 
                          ShowVisibilityType.NONE,
@@ -485,7 +490,7 @@ public final class TextDetail implements Selectable {
      * @see  TextDetail
      */
     static final class DetailNode extends AbstractNode
-                                          implements OutputListener {
+                                          implements OutputListener, Removable {
         private static final String ICON =
                 "org/netbeans/modules/search/res/textDetail.png";       //NOI18N
         /** Maximal lenght of displayed text detail. */
@@ -513,8 +518,6 @@ public final class TextDetail implements Selectable {
             this.txtDetail = txtDetail;
             this.mo = mo;
             
-            setValue(SearchDisplayer.ATTR_OUTPUT_LINE,
-                     DetailNode.getFullDesc(txtDetail));
             // A workaround for #124559 - when the detail becomes visible,
             // get the Line object. Later - if the user jumps to the document,
             // changes it and saves - the Line objects are not created for the
@@ -540,7 +543,10 @@ public final class TextDetail implements Selectable {
         @Override
         public Action[] getActions(boolean context) {
             if (!context) {
-                return new Action[] { getPreferredAction() };
+                return new Action[]{
+                    getPreferredAction(),
+                    SystemAction.get(HideResultAction.class)
+                };
             } else {
                 return new Action[0];
             }
@@ -557,7 +563,7 @@ public final class TextDetail implements Selectable {
                 boolean used = false;
                 for (SurroundingLine l : txtDetail.surroundingLines) {
                     if (txtDetail.getLine() == l.getNumber() - 1) {
-                        appendMarkedText(sb);
+                        appendMarkedText(sb, false);
                         sb.append("<br/>");                             //NOI18N
                         used = true;
                     }
@@ -565,7 +571,7 @@ public final class TextDetail implements Selectable {
                     sb.append("<br/>");                                 //NOI18N
                 }
                 if (!used) {
-                    appendMarkedText(sb);
+                    appendMarkedText(sb, false);
                 }
             } catch (CharConversionException e) {
                 return null;
@@ -620,7 +626,7 @@ public final class TextDetail implements Selectable {
                 text.append(": ");                                      //NOI18N
                 text.append("</font>");                                 //NOI18N
                 if(canBeMarked()) {
-                    appendMarkedText(text);
+                    appendMarkedText(text, true);
                 }
                 else {
                     text.append(escape(cutLongLine(txtDetail.getLineText())));
@@ -636,7 +642,7 @@ public final class TextDetail implements Selectable {
             }
         }
 
-        private String cutLongLine(String s) {
+        private static String cutLongLine(String s) {
             if (s == null) {
                 return "";                                              //NOI18N
             } else if (s.length() < DETAIL_DISPLAY_LENGTH) {
@@ -658,7 +664,7 @@ public final class TextDetail implements Selectable {
                    col0 < txtDetail.getLineTextLength(); // #177891
         }
 
-        private void appendMarkedText(StringBuilder sb)
+        private void appendMarkedText(StringBuilder sb, boolean trim)
                 throws CharConversionException {
             final int lineLen = txtDetail.getLineTextLength();
             int matchStart = txtDetail.getColumn0();  // base 0
@@ -685,7 +691,7 @@ public final class TextDetail implements Selectable {
                 prefixStart = 0;
                 suffixEnd = lineLen;
             }
-            appendMarkedTextPrefix(sb, prefixStart, matchStart);
+            appendMarkedTextPrefix(sb, prefixStart, matchStart, trim);
             appendMarkedTextMatch(sb, matchStart, matchEnd, lineLen, detailLen);
             appendMarkedTextSuffix(sb, matchEnd, suffixEnd, lineLen);
         }
@@ -696,14 +702,22 @@ public final class TextDetail implements Selectable {
          * @param text Buffer to append to.
          * @param prefixStart Line index of the first character to be displayed.
          * @param matchStart Line index of the matched text.
+         * @param trim Skip leading whitespace characters.
          */
         private void appendMarkedTextPrefix(StringBuilder text, int prefixStart,
-                int matchStart) throws CharConversionException {
-            if (prefixStart > 0) {
+                int matchStart, boolean trim) throws CharConversionException {
+            int first = 0; // index of first non-whitespace character
+            if (trim) {
+                String lineText = txtDetail.getLineText();
+                while (first < matchStart && lineText.charAt(first) <= '\u0020') {
+                    first++;
+                }
+            }
+            if (prefixStart > 0 && first < prefixStart) {
                 text.append(ELLIPSIS);
             }
-            text.append(escape(txtDetail.getLineTextPart(prefixStart,
-                    matchStart)));
+            text.append(escape(txtDetail.getLineTextPart(
+                    Math.max(prefixStart, first), matchStart)));
         }
 
         /**
@@ -908,7 +922,12 @@ public final class TextDetail implements Selectable {
         @Override
         protected void createPasteTypes(Transferable t, List<PasteType> s) {
         }
-        
+
+        @Override
+        public void remove() {
+            this.mo.removeDetail(txtDetail);
+        }
+
         @Override
         public boolean canDestroy() {
             return true;
@@ -916,7 +935,16 @@ public final class TextDetail implements Selectable {
 
         @Override
         public void destroy() throws IOException {
-            this.mo.removeDetail(txtDetail);
+            remove();
+        }
+
+        @Override
+        public Object getValue(String attributeName) {
+            if (SearchDisplayer.ATTR_OUTPUT_LINE.equals(attributeName)) {
+                return DetailNode.getFullDesc(txtDetail); // #236805
+            } else {
+                return super.getValue(attributeName);
+            }
         }
     } // End of DetailNode class.
 
@@ -955,7 +983,7 @@ public final class TextDetail implements Selectable {
 
         public SurroundingLine(int number, String text) {
             this.number = number;
-            this.text = text;
+            this.text = DetailNode.cutLongLine(text);
         }
 
         public int getNumber() {
