@@ -1,7 +1,7 @@
 /*
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
  *
- * Copyright 1997-2012 Oracle and/or its affiliates. All rights reserved.
+ * Copyright 1997-2014 Oracle and/or its affiliates. All rights reserved.
  *
  * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
  * Other names may be trademarks of their respective owners.
@@ -103,6 +103,7 @@ public class Utilities {
     public static final String UPDATE_DIR = "update"; // NOI18N
     public static final String FILE_SEPARATOR = System.getProperty("file.separator");
     public static final String DOWNLOAD_DIR = UPDATE_DIR + FILE_SEPARATOR + "download"; // NOI18N
+    public static final String RUNNING_DOWNLOAD_DIR = UPDATE_DIR + FILE_SEPARATOR + "download-in-progress"; // NOI18N
     public static final String NBM_EXTENTSION = ".nbm";
     public static final String JAR_EXTENSION = ".jar"; //OSGi bundle
     private static final SimpleDateFormat DATE_FORMAT = new SimpleDateFormat ("yyyy/MM/dd"); // NOI18N
@@ -156,9 +157,13 @@ public class Utilities {
     }
     
     public static Collection<Certificate> getCertificates (KeyStore keyStore) throws KeyStoreException {
-        List<Certificate> certs = new ArrayList<Certificate> ();
+        Set<Certificate> certs = new HashSet<Certificate> ();
         for (String alias: Collections.list (keyStore.aliases ())) {
-            certs.add (keyStore.getCertificate (alias));
+            Certificate[] certificateChain = keyStore.getCertificateChain(alias);
+            if (certificateChain != null) {
+                certs.addAll(Arrays.asList(certificateChain));
+            }
+            certs.add(keyStore.getCertificate(alias));
         }
         return certs;
     }
@@ -296,9 +301,7 @@ public class Utilities {
         try {
             try {
                 XMLUtil.write (doc, bos, "UTF-8"); // NOI18N
-                if (bos != null) {
-                    bos.close ();
-                }
+                bos.close ();
                 fos = new FileOutputStream (dest);
                 is = new ByteArrayInputStream (bos.toByteArray ());
                 FileUtil.copy (is, fos);
@@ -309,21 +312,17 @@ public class Utilities {
                 if (fos != null) {
                     fos.close ();
                 }
-                if (bos != null) {
-                    bos.close ();
-                }
+                bos.close ();
             }
         } catch (java.io.FileNotFoundException fnfe) {
             Exceptions.printStackTrace (fnfe);
         } catch (java.io.IOException ioe) {
             Exceptions.printStackTrace (ioe);
         } finally {
-            if (bos != null) {
-                try {
-                    bos.close ();
-                } catch (Exception x) {
-                    Exceptions.printStackTrace (x);
-                }
+            try {
+                bos.close ();
+            } catch (IOException x) {
+                Exceptions.printStackTrace (x);
             }
         }
     }
@@ -354,7 +353,7 @@ public class Utilities {
             content.append(UpdateTracking.PATH_SEPARATOR);
         }
         
-        if (content == null || content.length () == 0) {
+        if (content.length () == 0) {
             return ;
         }
         
@@ -435,7 +434,8 @@ public class Utilities {
         return res;
     }
     
-    static void writeUpdateOfUpdaterJar (JarEntry updaterJarEntry, JarFile updaterJar, File targetCluster) {
+    static void writeUpdateOfUpdaterJar (JarEntry updaterJarEntry, File zipFileWithUpdater, File targetCluster) throws IOException {
+        JarFile jf = new JarFile(zipFileWithUpdater);
         String entryPath = updaterJarEntry.getName();
         String entryName = entryPath.contains("/") ? entryPath.substring(entryPath.lastIndexOf("/") + 1) : entryPath;
         File dest = new File (targetCluster, UpdaterDispatcher.UPDATE_DIR + // updater
@@ -451,12 +451,12 @@ public class Utilities {
         try {
             try {
                 fos = new FileOutputStream (dest);
-                is = updaterJar.getInputStream (updaterJarEntry);
+                is = jf.getInputStream (updaterJarEntry);
                 FileUtil.copy (is, fos);
             } finally {
                 if (is != null) is.close();
                 if (fos != null) fos.close();
-                updaterJar.close();
+                jf.close();
             }                
         } catch (java.io.FileNotFoundException fnfe) {
             getLogger ().log (Level.SEVERE, fnfe.getLocalizedMessage (), fnfe);
@@ -617,7 +617,7 @@ public class Utilities {
         // handle diff
         for (String tok : oldTokens) {
             // don't care about provider of platform dependency here
-            if (tok.startsWith("org.openide.modules.os")) { // NOI18N
+            if (tok.startsWith("org.openide.modules.os") || tok.startsWith("org.openide.modules.jre")) { // NOI18N
                 continue;
             }
             dependencies.addAll(Dependency.create(Dependency.TYPE_REQUIRES, tok));
@@ -628,8 +628,7 @@ public class Utilities {
             DependencyAggregator deco = DependencyAggregator.getAggregator(d);
             int type = d.getType();
             String name = d.getName();
-            for (Iterator<ModuleInfo> it = deco.getDependening().iterator(); it.hasNext();) {
-                ModuleInfo depMI = it.next();
+            for (ModuleInfo depMI : deco.getDependening()) {
                 Module depM = getModuleInstance(depMI.getCodeNameBase(), depMI.getSpecificationVersion());
                 if (depM == null) {
                     continue;
@@ -996,9 +995,7 @@ public class Utilities {
             is = new BufferedInputStream (new FileInputStream (moduleUpdateTracking));
             InputSource xmlInputSource = new InputSource (is);
             document = XMLUtil.parse (xmlInputSource, false, false, null, org.openide.xml.EntityCatalog.getDefault ());
-            if (is != null) {
-                is.close ();
-            }
+            is.close ();
         } catch (SAXException saxe) {
             getLogger ().log (Level.INFO, "SAXException when reading " + moduleUpdateTracking, saxe);
             return null;
@@ -1030,7 +1027,7 @@ public class Utilities {
     private static Node getModuleLastVersion (Node version) {
         Node attrLast = version.getAttributes ().getNamedItem (UpdateTracking.ATTR_LAST);
         assert attrLast != null : "ELEMENT_VERSION must contain ATTR_LAST attribute.";
-        if (Boolean.valueOf (attrLast.getNodeValue ()).booleanValue ()) {
+        if (Boolean.valueOf (attrLast.getNodeValue ())) {
             return version;
         } else {
             return null;
@@ -1090,6 +1087,7 @@ public class Utilities {
         return m != null && !m.isEnabled () && ! m.isAutoload () && ! m.isEager ();
     }
     
+    @SuppressWarnings("null")
     public static boolean isElementInstalled (UpdateElement el) {
         assert el != null : "Invalid call isElementInstalled with null parameter.";
         if (el == null) {
@@ -1199,6 +1197,7 @@ public class Utilities {
         }
     }    
     
+    @SuppressWarnings("null")
     public static boolean canWriteInCluster (File cluster) {
         assert cluster != null : "dir cannot be null";
         if (cluster == null) {
