@@ -98,14 +98,14 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
     private SparseIntList knownLogicalLineCounts = null;
 
     /** Offset positions of tabs */
-    private IntList tabCharOffsets = new IntList(100);
+    private IntList tabCharOffsets = new IntList(128);
     /** Sums of length of all preceding tabs (length of extra spaces) */
-    private IntListSimple tabLengthSums = new IntListSimple(100);
+    private IntListSimple tabLengthSums = new IntListSimple(128);
 
-    private final IntListSimple foldOffsets = new IntListSimple(10);
-    private final IntListSimple visibleList = new IntListSimple(100);
-    private final IntListSimple visibleToRealLine = new IntListSimple(100);
-    private final IntListSimple realToVisibleLine = new IntListSimple(100);
+    private final IntListSimple foldOffsets = new IntListSimple(16);
+    private final IntListSimple visibleList = new IntListSimple(128);
+    private final IntListSimple visibleToRealLine = new IntListSimple(128);
+    private final IntListSimple realToVisibleLine = new IntListSimple(128);
     private int hiddenLines = 0;
 
     private int currentFoldStart = -1;
@@ -319,7 +319,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
 
     private void init() {
         knownLogicalLineCounts = null;
-        lineStartList = new IntList(100);
+        lineStartList = new IntList(128);
         lineStartList.add(0);
         lineCharLengthListWithTabs = new IntListSimple(100);
         linesToInfos = new IntMap();
@@ -679,7 +679,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         }
     }
 
-    private IntList importantLines = new IntList(10);
+    private IntList importantLines = new IntList(16);
 
     public int firstImportantListenerLine() {
         return importantLines.size() == 0 ? -1 : importantLines.get(0);
@@ -938,27 +938,29 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
     }
 
     public LineInfo getLineInfo(int line) {
-        LineInfo info = (LineInfo) linesToInfos.get(line);
-        if (info != null) {
-            int lineLength = length(line);
-            if (lineLength > info.getEnd()) {
-                // This is an input
-                info.addSegment(lineLength, OutputKind.IN, null, null, null, false);
-            }
-            return info;
-        } else {
-            // The last line can contain input
-            if (line == getLineCount() - 1) {
-                LineInfo li = new LineInfo(this);
-                try {
-                    li.addSegment(getLine(line).length(), OutputKind.OUT, null, null, null, false);
-                } catch (IOException e) {
-                    LOG.log(Level.INFO, null, e);
+        synchronized (readLock()) {
+            LineInfo info = (LineInfo) linesToInfos.get(line);
+            if (info != null) {
+                int lineLength = length(line);
+                if (lineLength > info.getEnd()) {
+                    // This is an input
+                    info.addSegment(lineLength, OutputKind.IN, null, null, null, false);
                 }
-                li.addSegment(length(line), OutputKind.IN, null, null, null, false);
-                return li;
+                return info;
             } else {
-                return new LineInfo(this, length(line));
+                // The last line can contain input
+                if (line == getLineCount() - 1) {
+                    LineInfo li = new LineInfo(this);
+                    try {
+                        li.addSegment(getLine(line).length(), OutputKind.OUT, null, null, null, false);
+                    } catch (IOException e) {
+                        LOG.log(Level.INFO, null, e);
+                    }
+                    li.addSegment(length(line), OutputKind.IN, null, null, null, false);
+                    return li;
+                } else {
+                    return new LineInfo(this, length(line));
+                }
             }
         }
     }
@@ -1212,11 +1214,14 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         }
     }
 
-    void checkLimits() {
+    int checkLimits() {
         synchronized (readLock()) {
-            if (getLineCount() > outputLimits.getMaxLines()
-                    || getCharCount() > outputLimits.getMaxChars()) {
-                removeOldLines();
+            if (getLineCount() >= outputLimits.getMaxLines()
+                    || getCharCount() >= outputLimits.getMaxChars()
+                    || linesToInfos.size() >= 524288) { // #239445
+                return removeOldLines();
+            } else {
+                return 0;
             }
         }
     }
@@ -1225,7 +1230,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
      * Tell the storage that oldest bytes can be forgotten, and update all data
      * structures.
      */
-    private void removeOldLines() {
+    private int removeOldLines() {
         int newFirstLine = Math.min(outputLimits.getRemoveLines(),
                 lineStartList.size() / 2);
         int firstByteOffset = lineStartList.get(newFirstLine);
@@ -1258,6 +1263,7 @@ abstract class AbstractLines implements Lines, Runnable, ActionListener {
         updateVisibleToRealLines(0);
         getStorage().shiftStart(firstByteOffset);
         fire();
+        return firstByteOffset;
     }
 
     private void recomputeRealToVisibleLine() {
