@@ -103,6 +103,7 @@ public abstract class Module extends ModuleInfo {
     protected ClassLoader classloader;
 
     private ModuleData data;
+    private NbInstrumentation instr;
     
     private static Method findResources;
     private static final Object DATA_LOCK = new Object();
@@ -611,6 +612,14 @@ public abstract class Module extends ModuleInfo {
         return false;
     }
 
+    final void assignInstrumentation(NbInstrumentation agent) {
+        instr = agent;
+    }
+
+    void unregisterInstrumentation() {
+        NbInstrumentation.unregisterAgent(instr);
+    }
+
     /** Struct representing a package exported from a module.
      * @since org.netbeans.core/1 > 1.4
      * @see Module#getPublicPackages
