@@ -482,12 +482,22 @@ public final class ExplorerManager extends Object implements Serializable, Clone
         }
 
         synchronized (LOCK) {
+            // a quick check if the context changes, in that case it's not necessary 
+            // to acquire Children.MUTEX read lock
             if (rootContext.equals(value)) {
                 return;
             }
+        }
 
-            class SetRootContext implements Runnable {
-                public void run() {
+        // now lock first Children.MUTEX and the private lock afterwards, someone
+        // might already have locked the Children.MUTEX
+        class SetRootContext implements Runnable {
+            @Override
+            public void run() {
+                synchronized (LOCK) {
+                    if (rootContext.equals(value)) {
+                        return;
+                    }
                     addRemoveListeners(false);
                     Node oldValue = rootContext;
                     rootContext = value;
@@ -505,10 +515,10 @@ public final class ExplorerManager extends Object implements Serializable, Clone
                     setExploredContext(rootContext, newselection);
                 }
             }
-
-            SetRootContext run = new SetRootContext();
-            Children.MUTEX.readAccess(run);
         }
+
+        SetRootContext run = new SetRootContext();
+        Children.MUTEX.readAccess(run);
     }
 
     /** @return true iff all nodes are under the target node */
@@ -1000,7 +1010,8 @@ bigloop:
                     // compare paths to root
                     Node n_selection = newSel.get(newSel.indexOf(n_remove));
 
-                    if (!Arrays.equals(NodeOp.createPath(n_remove, null), NodeOp.createPath(n_selection, null))) {
+                    if (!Arrays.equals(NodeOp.createPath(n_remove, null), NodeOp.createPath(n_selection, null))
+                            || isInParentChildren(n_remove)) {
                         it.remove();
                     }
                 }
@@ -1018,5 +1029,10 @@ bigloop:
             
             
         }
+
+        private boolean isInParentChildren (Node node) {
+            Node parent = node.getParentNode();
+            return parent != null && Arrays.asList(parent.getChildren().getNodes()).contains(node);
+        }
     }
 }
