@@ -93,8 +93,10 @@ import javax.swing.JComponent;
 import javax.swing.JFrame;
 import javax.swing.JLabel;
 import javax.swing.JPanel;
+import javax.swing.JScrollPane;
 import javax.swing.JTabbedPane;
 import javax.swing.KeyStroke;
+import javax.swing.ScrollPaneConstants;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.border.Border;
@@ -123,6 +125,7 @@ import org.openide.windows.WindowManager;
 public class OptionsPanel extends JPanel {
     private JPanel pCategories;
     private JPanel pCategories2;
+    private JScrollPane categoriesScrollPane;
     private JPanel pOptions;
     private JPanel quickSearch;
     private Color origForeground;
@@ -417,8 +420,13 @@ public class OptionsPanel extends JPanel {
         pCategories = new JPanel (new BorderLayout ());
         pCategories.setBorder (BorderFactory.createMatteBorder(0,0,1,0,Color.lightGray));        
         pCategories.setBackground (getTabPanelBackground());
-        pCategories.add ("Center", pCategories2);
+        categoriesScrollPane = new JScrollPane(pCategories2, ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER, ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
+        categoriesScrollPane.setBorder(null);
+        categoriesScrollPane.getHorizontalScrollBar().setUnitIncrement(Utils.ScrollBarUnitIncrement);
+        pCategories.add ("Center", categoriesScrollPane);
         pCategories.add ("East", quickSearch);
+        pCategories.setPreferredSize(new Dimension(pCategories.getPreferredSize().width, 
+                pCategories.getPreferredSize().height + categoriesScrollPane.getHorizontalScrollBar().getPreferredSize().height));
         
         // layout
         setLayout (new BorderLayout (10, 10));
@@ -852,21 +860,10 @@ public class OptionsPanel extends JPanel {
         buttons = new LinkedHashMap<String, CategoryButton>();
         
         // add new buttons
-        Dimension maxSize = new Dimension(0,0);        
         String[] names = categoryModel.getCategoryIDs();
         for (int i = 0; i < names.length; i++) {
             CategoryModel.Category category = categoryModel.getCategory(names[i]);
-            CategoryButton button = addButton (category);            
-            Dimension d = button.getPreferredSize();
-            maxSize.width = Math.max(maxSize.width, d.width);
-            // #141121 - ignore big height which can appear for uknown reason
-            if(d.height < d.width*10) {
-                maxSize.height = Math.max(maxSize.height, d.height);
-            }
-        }        
-        it = buttons.values().iterator ();
-        while (it.hasNext ()) {
-            it.next().setPreferredSize(maxSize);
+            addButton (category);
         }
         
         addFakeButton ();
@@ -1195,10 +1192,11 @@ public class OptionsPanel extends JPanel {
         }
 
         public void mouseEntered (MouseEvent e) {
-            if (buttons.get(category.getID()).isEnabled() && !category.isCurrent() && categoryModel.getCurrent() != null) {
-                setHighlighted ();
-            } else {
-                categoryModel.setHighlited(categoryModel.getCategory(categoryModel.getHighlitedCategoryID()),false);
+            CategoryButton button = buttons.get(category.getID());
+            if (button != null && button.isEnabled() && !category.isCurrent() && categoryModel != null && categoryModel.getCurrent() != null) {
+                setHighlighted();
+            } else if (categoryModel != null) {
+                categoryModel.setHighlited(categoryModel.getCategory(categoryModel.getHighlitedCategoryID()), false);
             }
         }
 
