@@ -51,6 +51,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStream;
+import java.nio.file.Files;
+import java.nio.file.Paths;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -71,6 +73,7 @@ import org.netbeans.modules.options.export.OptionsExportModel.State;
 import org.openide.filesystems.FileObject;
 import org.openide.filesystems.FileUtil;
 import org.openide.util.Exceptions;
+import org.openide.util.Utilities;
 
 /**
  *
@@ -280,6 +283,36 @@ public class OptionsExportModelTest extends NbTestCase {
         model.doImport(targetUserdir);
         assertFiles(expected, OptionsExportModel.getRelativePaths(targetUserdir));
     }
+
+    public void test239958() throws Exception {
+        // import from source userdir to current userdir
+        // exclude pattern equals with another include pattern leads to that pattern being skipped
+        createModel(new String[][]{
+                    {"Category0", "Item00", "dir0/subdir0/.*", "dir0/subdir1/.*"},
+                    {"Category0", "Item01", "dir0/subdir1/.*", null}
+                });
+        File targetUserdir = new File(getWorkDir(), "userdir");
+        targetUserdir.mkdir();
+        model.doImport(targetUserdir);
+        List<String> expected = new ArrayList<String>();
+        expected.add("dir0/subdir0/file0.properties");
+        expected.add("dir0/subdir0/file1.properties");
+        assertFiles(expected, OptionsExportModel.getRelativePaths(targetUserdir));
+
+        // import from zipped userdir to current userdir
+        // exclude pattern does not equal with another include pattern leads to that pattern being processed properly
+        File sourceZipFile = new File(getWorkDir(), "sourceUserdir.zip");
+        OptionsExportModel.createZipFile(sourceZipFile, sourceUserdir, OptionsExportModel.getRelativePaths(sourceUserdir));
+        createModel(new String[][]{
+                    {"Category0", "Item00", "dir0/subdir0/.*", null},
+                    {"Category0", "Item01", "dir0/subdir1/.*", null}
+                }, sourceZipFile);
+        targetUserdir = new File(getWorkDir(), "userdir1");
+        model.doImport(targetUserdir);
+        expected.add("dir0/subdir1/file0.properties");
+        expected.add("dir0/subdir1/file1.properties");
+        assertFiles(expected, OptionsExportModel.getRelativePaths(targetUserdir));
+    }
     
     public void test227906() throws Exception {
         createModel(new String[][]{
@@ -315,6 +348,22 @@ public class OptionsExportModelTest extends NbTestCase {
             Exceptions.printStackTrace(ex);
         }
     }
+    
+    public void test244640() throws Exception {
+        createModel(new String[][]{
+            {"Category0", "Item00", "dir0/subdir0/.*", null},});
+        ArrayList<String> enabledItems = new ArrayList<String>();
+        enabledItems.add("Category0Item01");
+
+        File targetZipFile = new File(getWorkDir(), "export.zip");
+        model.doExport(targetZipFile, enabledItems);
+        assertEquals(enabledItems, model.getEnabledItemsDuringExport(targetZipFile)); // reading enabledItems.info from zip file
+        
+        assertEquals(null, model.getEnabledItemsDuringExport(sourceUserdir)); // no enabledItems.info in user dir, e.g. version < 7.4
+        // first write the enabledItems.info in user dir
+        Files.write(Paths.get(Utilities.toURI(new File(sourceUserdir, OptionsExportModel.ENABLED_ITEMS_INFO))), "Category0Item01".getBytes());
+        assertEquals(enabledItems, model.getEnabledItemsDuringExport(sourceUserdir)); // reading enabledItems.info from user dir
+    }
 
     public void testImportProperties() throws Exception {
         // import from source userdir to current userdir
